##  Limitations
  * Currently, you cannot create new transformations in the transformations explorer. You can only manage existing ones.
  * Certain fields may be read-only based on permissions or system constraints.
